@@ -17,11 +17,6 @@ describe 'designate::api' do
 
   shared_examples 'designate-api' do
     context 'with default parameters' do
-      it 'includes the dependent classes' do
-        is_expected.to contain_class('designate::deps')
-        is_expected.to contain_class('designate::policy')
-      end
-
       it 'installs designate-api package and service' do
         is_expected.to contain_service('designate-api').with(
           :name      => platform_params[:api_service_name],
@@ -77,8 +72,8 @@ describe 'designate::api' do
           :default_limit_v2              => '25',
           :max_limit_v2                  => '1500',
           :pecan_debug                   => true,
-          :enabled_extensions_v2         => 'experimental',
-          :enabled_extensions_admin      => 'reports,quotas,counts,tenants,target_sync',
+          :enabled_extensions_v2         => 'ext1,ext2',
+          :enabled_extensions_admin      => 'reports,quotas,zones',
           :enable_proxy_headers_parsing  => true,
         })
       end
@@ -106,6 +101,20 @@ describe 'designate::api' do
       end
     end
 
+    context 'with enabled_extentions in list' do
+      before do
+        params.merge!({
+          :enabled_extensions_v2    => ['ext1', 'ext2'],
+          :enabled_extensions_admin => ['reports', 'quotas', 'zones']
+        })
+      end
+
+      it 'configure service_api' do
+        is_expected.to contain_designate_config('service:api/enabled_extensions_v2').with_value('ext1,ext2')
+        is_expected.to contain_designate_config('service:api/enabled_extensions_admin').with_value('reports,quotas,zones')
+      end
+    end
+
     context 'with custom package name' do
       before do
         params.merge!({ :api_package_name => 'designate-api-custom-name' })
